fauxmo.plugins package
======================

Submodules
----------

fauxmo.plugins.commandlineplugin module
---------------------------------------

.. automodule:: fauxmo.plugins.commandlineplugin
   :members:
   :undoc-members:
   :show-inheritance:

fauxmo.plugins.homeassistantplugin module
-----------------------------------------

.. automodule:: fauxmo.plugins.homeassistantplugin
   :members:
   :undoc-members:
   :show-inheritance:

fauxmo.plugins.simplehttpplugin module
--------------------------------------

.. automodule:: fauxmo.plugins.simplehttpplugin
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: fauxmo.plugins
   :members:
   :undoc-members:
   :show-inheritance:
